/**
 * @file
 * @brief This file contains the declarations of functions in process.c
 *
 */
#ifndef _PROCESS_H_
#define _PROCESS_H_

#include "sequence.h"

void calculate_distances(seq_t *sequences, size_t n);

#endif
